package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@("`0`````````````"`"L````!```````0'T``````````0```````
M`,[0```"`@!``#@`"`!``!L`&@````8````%`````````$```````!``0```
M````$`!``````````<`````````!P``````````(`````P````0````````"
M````````$`(````````0`@``````````%0`````````5``````````$````!
M````!0`````````````````0`````````!```````````+^\````````O[P`
M`````!````````$````'````````P````````"#`````````(,``````````
M#;@````````>$```````$````````@````8```````#`*```````(,`H````
M```@P"@````````"8`````````)@``````````@````$````!`````````(8
M```````0`A@``````!`"&`````````!$`````````$0`````````!&1TY5``
M```$````````O#```````!"\,```````$+PP`````````.0`````````Y```
M```````$9'3E40````8`````````````````````````````````````````
M``````````````````````@O;&EB-C0O;&0M;&EN=7@N<V\N,@`````````$
M````$`````%'3E4```````````(````&````(`````0````4`````T=.50!Y
M`YP1X,$8X%3`.%U25"=X?P_QF`````````!#````!@````@````)Q&%G@C*$
M`*(["6$&2$)[#!41(1U*`AJ#$`"R(@!`0(0@DI0`"$*``@+`H%1AFB`*'0)0
M0"!%#$`I9+\(U2>2-``````````&````!P````@````)````#``````````1
M````$@```!0````6````&0```!L``````````````!P````?````(````"$`
M```D````)@```"@````J`````````"P````M````+@```#`````Q````,@``
M`#,`````````````````````````-0```#<````X````.0```#L`````````
M/``````````]````0````$(```!$````1@```$@`````````2@````````!+
M````30```$\```!0````40```%,```!4````5@```%@`````````6@```%L`
M``!<````70`````9]@*C<;+5R<6%<VU@=E]>(N'0*J]E`*/_KDK.D.]:HAC$
M5^*?RJO>J,<BGY`'J5.O##_,R._R0\VR;`3I$)!]#3FM/,+#^^@"D#_M_X>D
M!G#C;W>D^2,!]CU.+M;K52SQ6NH7D`6)Q6M*\'L02V9"#8)T@&($K9-G:)*@
M&'SHFP[OT^I7-=F+P?#C-@V"=9$<DY9>?);PA[W6GQO"W9B+41`"'`[QC;D"
ML'0AB_8L[>>=2+%`G+G$(DE)9WR=34"H#?PIA:4R!1R3WNUHU"*8R6A:3VNC
MW:=SL0XM/>`.QH&<^88<D[N=7@#WVA+OF&%(_M\L?)9^/X+ZT&(5(NO?^FEZ
M;E):DE</.YI:^5$+[^S514,?0#M8A#"$<2AW4N!/((7?A`11TQ]`.<D@SB/V
M?)+CN_PLG]$<D]M6?4O0O5]]&U`-@K@Q_X>.PAR3E;O>3F\U'=/;\P_OTOW_
M?2)*'%AQV0`````````````````````````````````````=````````````
M``(````````````````=``````````````,`````````````!-`=````````
M``````<```````````````P@`````````````````````````````!L@````
M`````````````````````````B,2```````````@QD```````````````;X2
M```````````@Q&``````````````!`(2```````````@QV``````````````
M`3`2```````````@QZ``````````````!%@2```````````@R.``````````
M`````.T2```````````@RF```````````````X42```````````@PX``````
M`````````S$2```````````@Q:``````````````!$02```````````@QH``
M`````````````CP2```````````@QT``````````````!&(2```````````@
MR\```````````````742```````````@Q4```````````````W02````````
M```@QL```````````````0P2```````````@S8```````````````WP2````
M```````@R&```````````````$\2```````````@S*```````````````I@2
M```````````@Q2```````````````-@2```````````@RR``````````````
M`DH2```````````@S&``````````````!"T2```````````@P^``````````
M````!`T2```````````@S(```````````````R`2```````````@R0``````
M````````!(82```````````@RJ```````````````@42```````````@RT``
M````````````!'@2```````````@S$``````````````!)DA```8```````@
MS;@`````````"````G$2```````````@R"```````````````^<2````````
M```@Q<```````````````[T2```````````@QX```````````````SD2````
M```````@RP```````````````902```````````@Q.```````````````&02
M```````````@S.```````````````5$2```-```````07&``````````````
M`'D2```````````@S6```````````````F,2```````````@R:``````````
M`````^T2```````````@S2``````````````!'\2```````````@R(``````
M`````````:T2```````````@R^``````````````!'`2```````````@QJ``
M`````````````/X2```````````@QB```````````````)`2```````````@
MS0```````````````%X2```+```````0'$``````````````!!42````````
M```@Q0```````````````HP2```````````@RX```````````````5<2````
M```````@RZ``````````````!)@1```8```````@S;@`````````"```!!\2
M```````````@Q^```````````````QL2```````````@RV``````````````
M`=\2```````````@S,```````````````E42```````````@R<``````````
M`````\L2```````````@Q@```````````````:@2```````````@P\``````
M`````````#T2```````````@RH``````````````!)HA```8```````@S;@`
M````````"````"\2```````````@Q\```````````````[42```````````@
MR````````````````*$2```````````@R$```````````````](2````````
M```@S4```````````````XX2```````````@Q$```````````````Q02````
M```````@S````````````````C,2```````````@Q>```````````````V\2
M```````````@R2```````````````I\2```````````@QN``````````````
M`?$2```````````@QP```````````````UT2```````````@Q8``````````
M`````;(2```````````@R>```````````````TT2```````````@Q(``````
M````````!#02```````````@QR``````````````!*(0`/_Q```````@S;@`
M`````````````602```````````@R*```````````````1X2```````````@
MS"```````````````+(2```````````@PZ```````````````4(2````````
M```@R4```````````````H$2```````````@Q"```````````````Y<2````
M```````@R@```````````````Z@2```````````@RL``````````````!+40
M`/_Q```````@WA``````````````!#T2```````````@RN``````````````
M`^`2```````````@Q*```````````````,D2```````````@R,``````````
M`````=$2```````````@QF```````````````]D2```````````@RD``````
M`````````\02```````````@R8``````````````!%$2```````````@RB``
M`````````````8<2```````````@Q6```````````````JH1```8```````@
MS<``````````$P```Z\2```````````@R6```````````````_02````````
M```@Q```````````````!*D0`/_Q```````@S;@```````````!L:6)P97)L
M+G-O`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`4&5R;%]S
M>7-?=&5R;0!097)L7TES=&%T8G5F7W!T<@!097)L7W-Y<U]I;FET,P!?:6YI
M=`!097)L7TEE>&ET7V9L86=S7W!T<@!097)L7W-A=F5?9&5S=')U8W1O<E]X
M`%!E<FQ?26-O;7!C=E]P='(`4&5R;%]A=&9O<FM?;&]C:P!097)L7TEC=7)S
M=&%C:VEN9F]?<'1R`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?27!A<G-E<E]P='(`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P
M=E]F;&%G<P!097)L7TET;W!?96YV7W!T<@!097)L7TET86EN=&5D7W!T<@!0
M97)L7W-V7W-E='!V;@!?9FEN:0!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F
M;&%G<P!097)L7TEI;E]E=F%L7W!T<@!097)L7TEO<%]P='(`4&5R;%])979A
M;%]R;V]T7W!T<@!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]'=&AR7VME>5]P='(`4&5R;%]'
M9&]?=6YD=6UP7W!T<@!097)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE
M=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!0
M3%]M96UO<GE?=W)A<`!L:6)R97-O;'8N<V\N,@!L:6)N<VPN<V\N,0!L:6)D
M;"YS;RXR`&QI8FTN<V\N-@!L:6)C<GEP="YS;RXQ`&QI8G5T:6PN<V\N,0!L
M:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`7U]E<G)N;U]L;V-A=&EO;@!L
M<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB8RYS;RXV`%]?
M<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!G971P=W5I
M9`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I
M<@!?7WAS=&%T-C0`7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI;FL`97AE
M8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C
M:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQI8C8T+W!E
M<FPU+T-/4D4`7U]T:')E861?<V5L9@!'3$E"0U\R+C(`1TQ)0D-?,BXT`$=,
M24)#7S(N,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N-```````````````````
M``````(````"`````@`$``,````#`````@````(````"```````"``(`!``"
M`````@`"`````@`"``0```````$```````(``@`"``(```````$``@``````
M`@`&``0```````(```````(````"`````@`"``0````"```````%````!``"
M``$```````````````<``@`!``(``@```````@`"``(```````(``P`!````
M``````$``0```P0````0````(`UI:1(````$```$W@```````0`%```#4P``
M`!``````#6EI%`````<```3H````$`UI:1,````&```$\@```!`):1ER````
M!0``!/P````0"6D9=`````,```4(````$`UI:1(````"```$W@``````````
M`"#"D`````0````4`````````````````"#-N````#,````3````````````
M`````"#-P````%L````3`````````````````"##@`````P````5````````
M`````````"##H````$T````5`````````````````"##P````#D````5````
M`````````````"##X````!D````5`````````````````"#$`````%T````5
M`````````````````"#$(````$\````5`````````````````"#$0````$``
M```5`````````````````"#$8`````<````5`````````````````"#$@```
M`$@````5`````````````````"#$H````%0````5`````````````````"#$
MP`````0````5`````````````````"#$X````"0````5````````````````
M`"#%`````#`````5`````````````````"#%(````!8````5````````````
M`````"#%0````!$````5`````````````````"#%8````%H````5````````
M`````````"#%@````$8````5`````````````````"#%H`````T````5````
M`````````````"#%P````"$````5`````````````````"#%X````$(````5
M`````````````````"#&`````#@````5`````````````````"#&(````"T`
M```5`````````````````"#&0`````8````5`````````````````"#&8```
M`%8````5`````````````````"#&@`````X````5`````````````````"#&
MH````"P````5`````````````````"#&P````!(````5````````````````
M`"#&X````$0````5`````````````````"#'`````$4````5````````````
M`````"#'(````$D````5`````````````````"#'0`````\````5````````
M`````````"#'8`````@````5`````````````````"#'@````"(````5````
M`````````````"#'H`````D````5`````````````````"#'P````#P````5
M`````````````````"#'X````#0````5`````````````````"#(`````#T`
M```5`````````````````"#((````"`````5`````````````````"#(0```
M`#X````5`````````````````"#(8````!0````5`````````````````"#(
M@````"H````5`````````````````"#(H````$L````5````````````````
M`"#(P````%4````5`````````````````"#(X`````H````5````````````
M`````"#)`````!L````5`````````````````"#)(````$,````5````````
M`````````"#)0````$X````5`````````````````"#)8````%P````5````
M`````````````"#)@````%@````5`````````````````"#)H````"@````5
M`````````````````"#)P````#<````5`````````````````"#)X````$<`
M```5`````````````````"#*`````%`````5`````````````````"#*(```
M`%D````5`````````````````"#*0````%<````5`````````````````"#*
M8`````L````5`````````````````"#*@````#H````5````````````````
M`"#*H````!P````5`````````````````"#*P````%$````5````````````
M`````"#*X````%,````5`````````````````"#+`````",````5````````
M`````````"#+(````!<````5`````````````````"#+0````!T````5````
M`````````````"#+8````#4````5`````````````````"#+@````#$````5
M`````````````````"#+H````#(````5`````````````````"#+P````!``
M```5`````````````````"#+X````"L````5`````````````````"#,````
M`$$````5`````````````````"#,(````$P````5`````````````````"#,
M0````!X````5`````````````````"#,8````!@````5````````````````
M`"#,@````!H````5`````````````````"#,H````!4````5````````````
M`````"#,P````#8````5`````````````````"#,X````"4````5````````
M`````````"#-`````"X````5`````````````````"#-(````"D````5````
M`````````````"#-0````#\````5`````````````````"#-8````"<````5
M`````````````````"#-@````!,````5``````````"=X[]0+P`$*4```,RN
M!>)``P```((88`C"7<`!`L!`!`$```!`!"H7`0```$```.T!````0``/XP$`
M``"!S^`(`0````````````````````````````````````````"=X[]`D`>H
M?Y('J(?R=ZB'E`>HC_1WJ(]`!"OZ\">H?Q,`"#$1``@RDA)@8)`2($!```^4
ME!``"4`$*HJ0$"``PDH``("@8``22``0`0```$`$*GP!````!0`(-P+"`(G0
M<*((0`0J[P$```!`!"OMD!`@`$`$*WO0`@``0`0KB0$```#`*@``0`0KYI`0
M(`!`!"MTT`(``$`$*^H!````@A``")`0(`#$"$``A!"@`D`$*]S$*$``0`0K
M:M`"``!`!"O@`0```,(*``""$&`!PBH``-`'J'^0`B`%D3H@``;"`%N#,C`!
MT'>G]]$?I_>5H!$(D;`,`((0(0^#*'`VPG>G[Y6BB$C1'Z?O@:J*R"U``%X1
M``070`0K<I$J,`/*7ZB'!P`(-X(0``C4!ZA_Q%E``-!PX?"&$"`$@**@`<1R
M```%``08A!"@`,1R(`@%``08A!"@.,1R(!`%``08A!"@",1R(!@%``@W!$``
M#L8@H?BZ`K_^A!`@`+LW8`"Z!V`!NR]P`X@!0`*&`$`"R%D@"(0`H`B`H(`=
M$F__^\APX""$`J`$.P`(-X4XH`"4`J`#T%]B"(0`O_\3``00A2BP`Y(28@"5
M.J``EA```<!P0`)`!"EKF!`@`+"2(``"0``0`0```$`$*L[07V(($0`$%T``
M!PN0$B%P`L(`#3D`"#?07V((0`0I1K$^(`!`!"I$`0```('/X`@!````0`0I
MR-!?8@@0;__PL!``"-!?(@`BP@`-$0`$%T``#MD!````$&__\=!?8@B$"B`!
M@A!``L)WI_?1'Z?WE:`1"!!O_Z65HHA*0``&[I`2(/@"^C_ET'<B`!!O__$!
M````0`0J@)`0(`$3``@SD!(C^$`$*OR2$F'``0````$```"\$```G".@,-);
MJ*^4`ZBW$0`$!Q<`!!89``06D!(@H)82XV"8$R/@FA```4`$*LT!````````
M`('#X`BN`\`7G>._4#4`"#/"#J'8@*!@`!)``!HW``@P.0`(,+86X!"X%R`8
M.P`(,[@G`!O"7V'@N3\P`[@'/_^`H$`<.F``#H(0(`&Z%V'@@@!@`<)W0`"#
M*'`#PE[``9_`0``!````PE]``("@0!P*;__Y@@!@`8(0(`'"+J'8@<_@"`$`
M``"=X[]0@<_@"`$````P:``%`0````$````!`````0```)WCOU`1``@PPEH@
M(`+`0`B0$B`@`P```((08``"P$`$`0```)_`0``!````@<_@"`$````P:``#
M`0````$```"=X[]0@<_@"`$````P:``%`0````$````!`````0```)WCNL"*
M$#__A`8@.(('I7^Z!Z7_BS%P(,98@`"),/`@A@C`!<AP0`#&<&`(@@!@$("@
M0!T2;__YA`"@"((0/_^&!Z7G@S!P(+8'I^?X6/_8R%C``/I8_ZC*6/^8B!\`
M!(@9`!V(&0`%BS$P'X@!``2($4`$B`D``<APX!B&`.`(@*#`&Q)O__*$$``!
MWEX```L6H)X)&[9ZTEX@((H189F($2.A]E^E?[LK\`4'(\;OUEX@"+DS\!N&
M$.#<U%X@$+8"0!NX%P`=VEX@&+@/``&V!L`%N@J`"[8&P!S87Z6'M"M`"[@J
M@`_07Z67NA:`'9@#0`S27Z6/M3+P`KH&P!WJ7Z6?MRKP'KH/0`'N7Z6GM!:`
M&Y@#``7H7Z7'M`Z``9`"``7L7Z7/M@Z`#YHN@!WB7Z6OLS=P&[86P!SF7Z6W
MN2]P!;8#`!O@7Z6_N!9`')`"`!JX#P`!D@*`";,S\`*V!L`<N2OP'K8.P`&X
M%D`<D@)`!;@/``&J!4`%M`]`'+(O`!N9-O`;M!-`&ILN\`6J!4`<FA,`#;0"
M0!J:"T`!K@7`!;DW<`*T!H`-NR]P'I(.@`&Z%P`=^%^F3Z($0`6T#T`!^E^F
M5Z8$P`68#L`:I"Z`"9LR<!N8%D`,LRIP!:X%P!KT7Z9GLA-`&9@"``S:7Z9O
ML@Y``?1WH^>@!``%M3;P`I@#`!GR7Z9WMR[P'MIWH^^8"P`!VE^F?[86@!NT
M!8`%\G>C][(%``6V#L`!Z%^FAZ($0!OL7Z:/VG>C_YH*0!OH=Z0'FA2`#>A?
MII>:!4`-Y%^FG^QWI`^L+L`,Z'>D%ZDS,!O07Z9?Y'>D'Z4K,`7J7Z:GJ!4`
M$I`"``3V7Z:OJ`T``>IWI">:`T`4ZE^FMYH+0`'D7Z77Z%^FO^IWI#?J7Z;'
M]G>D+[8$@`6E,G`"Z'>D/Y,J<![H7Z;/ZG>D1Y(4@`GJ7Z7GD@I``>1?I=^J
M!4`%Z'>D3Z@+``FD!(`%ZG>C=ZP5@!3J7Z;?K`7`%NA?IN?D=Z-OY%^FU^IW
MI%^K,W`;Z'>D9ZDK<`7N7Z;OJ!5`%.1WI%>D*D`-D@3`">I?I>^H#0`!YE^F
M]Z@%@!3N=Z1OK@5`!:@-``'J7Z<'YG>D=^9?IO_L7Z</YG>D?Z<S,`+J=Z2'
MF2LP'NQWI(^8%,`,ZE^G%Y@+``'L7Z7_YE^E]^IWI)>J"T`,K`6`!:04@!6F
M!,`%ZE^G+^QWHX>B!$`2[%^G)^1?IS?F=Z-_YE^G'^QWI*>M-3`;ZG>DKZLM
M,`7D=Z2WJA6`%>1?IT>J#4`![%^G/Z($0!7F=Z2?IBL`%)@$``S@7Z8'H@Q`
M`>1WI,?D7Z=7['>DOZP$``6A,W`"ZE^G3YLK<![D=Z37FA0`#>1?IU_@7Z8/
MF@M``>IWI,^R!D`-J@0`!>1WI-_@7Z87Y%^G9XH$``6@#0`-RG>CC^1WI.>F
M%,`0BBM`$>1?IV^2`D`3X%^G=^1WI.^E-'`;X'>D]Z$L<`6@%(`0Y%^F'^9?
MIW^@#``!I`2`!-I?IX>2`D`0YG>D_Y(*0`'F7Z>/X%^GE^1WHY?D7Z>?VG>E
M!YLU,`+F=Z4/J2TP'N9?IB>:$T`4X'>E%^1WI1^H!,`$X%^GI^1?IB_F7Z>O
MI`2`!.!WI2>@"T`!Y'>CGZ0,0!":+``)YG>E+XH10!*T!H`0YE^GMXH#``7D
M7Z>_X%^GS^9WI3>G,G`;Y'>E/Z4J<`6D%,`2X'>E3Z0,@`'@7Z?7V%^GQXH!
M0!+D7Z??B@E``>!WI5?@7Z?GV'>E1^1WI5_87Z8WX'>E9^1?IC^F`P`$F31P
M`N!?I^^C+'`>I`2`!.1WHZ>8$P`1Y%^F1Y@+``'@=Z5OH@I`#*0$@`3D=Z.O
MFA-`$>!?I_>V!L`,I3%P&[(&0`VC*7`%X'>E=Z`K``6B%(`1I`<`!+DR<`*B
M#$`!DRIP'K(&0!&X%P`)H@=`!-)?HV^Z#P`!L@Y``9H)0!VX+T`9F39P&Z`4
M``V;+G`%M`:`$)H3``W87Z/GN@)`'9H+0`'27Z/WH`,`!+0&@`W:7Z/OF3%P
M`K0.@`&+*7`>D@)`!-)WH[>*$P`%F@-`!-IWHV^3-K`;B@E``9@.0`6:*4`:
MN!<`#)DNL`6X!L`<]E^C=Y@20`S27Z/_F`L``8H&P`6X!P`,V%^D!Y("0`2W
M-G`"N`\``=)WHW>S+G`>F`,`!-AWH[^3-S`;MA;`&?)?I`^V#L`!F`Z`&[(&
M0`3R=Z/'FA-`#+(NP!R9+S`%N@=`#9@20`S27Z07M@7`&YLVL`*8"P`!N@=`
M#-A?I!^N`D`$M2ZP'KH/0`&T$T`:F`,`!-AWH\_:7Z0GDS=P&[0.@`&8#P`:
MLA9`#)H#0`3:=Z/7B@%`&?)?HW^:+H`=F2]P!;0&0!J8$D`,\E^D+Y@+``&2
M!D`$B@%`#-A?I#>S-S`"B@E``;DO,!Z(`P`$R'>C?YDQ<!NX%D`<\E^D/X@/
M``&R!D`#\G>CW[@I``6R#T`$FA-`&;,I<`6V!L`-VE^D1[(3`!G87Z.'F@-`
M`]IWHX>R#D`!FS=P`H@#``387Z17NR]P'K8&P!GR7Z1/NA-`';8.P`&Z#T`!
MF`,``]AWH^^:"4`=L@9``_)WH^>9-O`;N!<`#9LN\`6X!H`<]%^D7YH3``VR
M+T`;V%^D9YH+0`&Z!8`=N`<`#:P&@`/:7Z1OM3%P`K@/``&+*7`>F@-``]IW
MH_^*%H`%F`,``]AWH_>9-S`;B@E``9H.P`6T*4`<LA9`#8H%0`6;+S`%B`$`
M&?)?I'>:$P`-V%^D?YH+0`&J!D`#B`$`#=I?I(>8`P`#LS;P`H@)``'8=Z0'
MMR[P'IH#0`/:=Z0/F3$P&[860!NV#L`!F@\`&[(NP`2T%H`-FRDP!;H'0!KT
M7Z./FA,`#=A?I(^:"T`!M@:`&[H'0`W:7Z27F`,``[4W,`*Z#T`!V'>CC[DO
M,!Z:`T`#VG>D%YDW<!NX%H`<]%^DG[@/``&:"0`<M`:``_1WI!^R%D`-M"\`
M'9LO<`6*`4`9\E^DIYH3``W87Z.7L@9``_)WHY>:"T`!LS$P`K@#`!S87Z2O
MB2DP'HH!0`W:7Z2WB!9`!(H)0`&("0`!F`,``]AWI">R#T`$F@-``]IWI"^T
M%H`9\E^DOZ@%``29*7`%M@;`&O1?I,>;,7`;L@9``_)WI#>T!H`#FA-`#-A?
MI,^:"T`!]'>D/[4W<`*8`P`#V'>D1[LO<!ZV!L`-VE^DU[H6@!WR7Z.?M@[`
M`;H/0`&&`T`#QG>D3X@?0`2T!D`=VE^D[X<N\`6(&0`%V%^DY[,V\!NX!P`$
MB3%P`K(60`.+*7`>L@Y``8@1``4',IBPRE^DWX80X=:X!P`9N`\``8H!0`/*
M=Z.?LS<P&X@)``&++S`%NAD`'8H60`7R7Z3WNA]`&[H%`!V*"4`!L@9``_)W
MI%^*!T`%LS;P`J@#0`/:7Z.GMR[P'HH)0`&Z%D`;]E^D_Z8$P`2Z#T`!F`,`
M`]AWI%>V!L`#B!]`!/9WI&>S,7`;M@-`'=A?I0>:&0`<B2EP!;0&@`W:7Z4?
MB!9`!/)?I0^8`P`#B`D``9H#0`/8=Z1OL@9``_)WHZ>(!H`$LS<P`H@)``'8
M7Z47N2\P'MIWI'^X%D`<\E^E)Y@#``.X#P`!V'>D=[(&0`.Z'P`=\G>DA[,Q
M,!N:'T`%V%^CK[LI,`6:!,`-NA9`'?)?I2^T`P`<N@]``=A?I3>F!D`#N@-`
M'=I?I3^S,7`"N@]``8LI<!Z8`P`#V'>CKXH60`7R7Z5'F@-``XH)0`':=Z2/
ML@9``[@90!SR=Z27FA\`!-A?I4^D!(`%LS=P&[8&P`W:7Z57N2]P!9@#``/8
M=Z2?N!9`')H#0`/:=Z2GLS$P`K@/``':7Z5WB2DP'K@&P!SV7Z5GB!9`!/)?
MI5^X#P`!B`D``;8&P`/87Z5OL@9``XH9``7R=Z2O]G>DM[(90!V8`P`#MS<P
M&X8#0`/&=Z3'BR\P!;0&@!G8=Z2_BA;`!:($0`387Z._AS=P`HH)0`&[+W`>
MB@:`!880P!V*"4`!MS%P&X8(P`&[*7`%B!C`!+H6P!V(&0`<N@]``8@$@`3D
M7Z-OMS<P`H@!`!VY+S`>B`D``;H6P!R0`@`#M3$P&[H/0`&Y*3`%AA]``[@6
M@!R&&,`%N`\``88$0`.W,7`"A@#`'(LI<!Z&",`!BA;`!:`$`!VU*/`%B@E`
M`;DP\!NZ&4`=N!<`&KH?0`2X#P`!N@(`';H'0!RV!(`%Y%^CU[4Q,`*Z#T`!
MB2DP'K,O<`6(%H`$N3=P&X@)``&X%P`9\E^CMXH9``6*&4`#N`\``;0&0`2*
M!``%X%^CS[,P\`**`4`<ARCP'HH)0`&;*7`%AA9``[DQ<!N&",`!B!C`!+@7
M``V(&0`=N`\``8@&P`3V7Z-WB`$`'+(&P`.("0`!MS=P`KLO<!Z;*3`%NA;`
M';DQ,!NZ#T`!AA]``[@7``V&&,`%N`\``88&@`.V`P`=M3%P`H8`P!R+*7`>
MA@C``9LH\`6*%H`%N3#P&XH)0`&Z&4`=N!<`#=I?H\>Z'T`$N`\``;H&0!VT
M`T`%LS$P`KH'0!R)*3`>N@]``9LO<`6(%D`$N3=P&X@)``&*&0`%N!<`#8H9
M0`.X#P`!B@;`!:X%P`2W,/`"B@%`'(<H\!Z*"4`!LREP!886P`.Y,7`;A@C`
M`8@8P`2X%P`9B!D`';@/``&(!H`$M@0``^!?H_^U-W`"B`$`'+LO<!Z("0`!
MLRDP!;H6@!VY,3`;N@]``88?0`.X%P`9AAC`!;@/``&S,7`"A@7``^Y?HW^+
M*7`>A@#`'(H60`6&",`!B@E``;0$@!WD7Z0'FRCP!;H90!VY,/`;NA]`!+@7
M``VZ!L`=N`\``9("0`6W,3`"N@=`'(DI,!ZZ#T`!LR]P!8@6P`2Y-W`;B`D`
M`8H9``6X%P`9BAE``[@/``&*!H`%M@7`!.Y?HX^U,/`"B@%`'(<H\!Z*"4`!
MLREP!886@`.Y,7`;A@C``8@8P`2X%P`9\E^CWX@9`!VX#P`!M`9``X@"0`32
M7Z/GLS=P`H@!`!R[+W`>B`D``9LI,`6Z%D`=N3$P&[H/0`&&'T`#N!<`#;(8
MP`6X#P`!AS%P`K8&P!F+*7`>N`;`'(80P`6*#P`!^%^CAYDI<`6&",`!LA#`
M';8'`!VR"0`9N@C`';H60!VX`D`#TE^D%YLQ<!NT!H`=NS$P`IH30`S87Z/O
MB2DP'IH+0`&Z%T`$B`:`#;H/0`&("0`!LA=``X8/0`.R"4`9M`,`'9LQ,!N&
M%D`#F2DP!;8&P`.',7`"FA-`#(LI<!Z:"T`!BA#`!88&P`V*"4`!A@C``;81
M0!VZ"4`=M@D`&ZP%@`6;*/`%NA;`';,P\!NX!P`=NS$P`K(60`W:7Z/WB2DP
M'K(.0`&Z%T`$B`<`&;H/0`&("0`!MA=`!8H/0`6V",`;N`-`';,Q,!N*%L`%
MFRDP!;0&@`6+,/`"LA9`#8<H\!ZR#D`!BA%``X8&@!F*"4`!A@C``;010!VZ
M"4`=M`D`&K8$``7@7Z0GFRCP!;H6@!VS,/`;K`6`';LQ,`*R%D`-B2DP'K(.
M0`&Z%T`$B`6`&>Q?I`^Z#T`!B`D``;070`6*#T`%M`C`&JH%0!V;*3`%BA:`
M!;,Q,!NX!P`%BS#P`K(60`V'*/`>L@Y``8H10`.&!P`9B@E``88(P`&T$4`=
MN@E`';0)`!JX!(`%Y%^D+YLH\`6Z%H`=LS#P&[8&P!V[,3`"LA9`#8DI,!ZR
M#D`!NA=`!(@&P!FZ#T`!B`D``;070`6*#T`%M`C`&K8%@!WL7Z0_FRDP!8H6
M@`6S,3`;J@5`!8LP\`*R%D`-ARCP'K(.0`&*$4`#A@5`&>I?I#>*"4`!A@C`
M`;(10!VZ"4`=L@D`&;0%P`7N7Z1'F2CP!;H60!V;,/`;N`<`';LQ,`*:$T`,
MB2DP'IH+0`&Z%T`$B`<`#;H/0`&("0`!LA=`!8H/0`6R",`9N`)`'=)?HY^9
M*3`%BA9`!9LQ,!NV!L`%BS#P`IH30`S87Z0?ARCP'IH+0`&*$4`#A@;`#8H)
M0`&&",`!LA%`';H)0!VR"0`9M@,`!9LP\!NZ%D`=F2CP!;0&@!V[,3`"FA-`
M#(DI,!Z:"T`!NA=`!(@&@`W:7Z.7N@]``8@)``&R%T`%B@]`!;((P!FT`T`=
MF2DP!8H60`6;,3`;N`<`!8LP\`*:$T`,ARCP'IH+0`&*$4`#A@<`#8H)0`&&
M",`!LA%`';H)0!VR"0`9N`0`!>!?I&>9*/`%NA9`'9LP\!NV!L`=NS$P`IH3
M0`R)*3`>F@M``;H70`2(!L`-N@]``8@)``&R%T`%B@]`!;((P!FV!(`=Y%^D
M;YDI,`6*%D`%FS$P&[0&@`6+,/`"FA-`#(<H\!Z:"T`!BA%``X8&@`V*"4`!
MA@C``;(10!VZ"4`=L@D`&;0%0`7J7Z1WF2CP!;H60!V;,/`;N`<`';LQ,`*:
M$T`,B2DP'IH+0`&Z%T`$B`<`#;H/0`&("0`!LA=`!8H/0`6R",`9N`6`'>Q?
MI'^9*3`%BA9`!9LQ,!NV!L`%BS#P`IH30`S87Z17ARCP'IH+0`&&$4`#M@;`
M#88(P`&"#L`!MA#`';H(P!VV"0`;B@7``^Y?I(>;*'`%NA;`';,P<!NT!H`=
MNS$P`K(60`V)*3`>L@Y``KH70`2(!H`9\E^D3[H/0`*("0`"M!=``X8/0`.T
M"$`:M@9`'9LI,`6&%H`#LS$P&[@'``.','`"LA9`#8,H<!ZR#D`"AA#``8('
M`!F&",`"@@A``K00P!VZ",`=M`D`&K@"0`/27Z2?FRAP!;H6@!VS,'`;B@%`
M';LQ,`*R%D`-B2DP'K(.0`*Z%T`$B`%`&;H/0`*("0`"M!=``X8/0`.T"$`:
MB@,`'=A?I*>;*3`%AA:``[,Q,!NV!L`#AS!P`K(60`W:7Z1?@RAP'K(.0`*V
M!L`9AA#``88(P`*"#L`"M3!P&[H8P!VW*'`%NA]`!+86@!NX!P`=M@[``J@%
M``.[,3`"N`<`&XDI,!ZZ%T`$B`\``K4Q,!NZ#T`"AA]``[@#0!VW*3`%AAC`
M`;86@!N*`4`#AS!P`K8.P`*#*'`>B@%`&X80P`&""4`"M3!P&X8(P`*Z&,`=
MB@0``^!?I+>W*'`%NA]`!+86@!NH!0`=NS$P`K8.P`*)*3`>M@4`&^A?HZ>Z
M%T`$B`[``K,Q,!NZ#T`"AA]``[8$@!WD7Z2_M2DP!888P`&T%D`:N`<``X<P
M<`*T#H`"@RAP'K@'`!J&$,`!@@\``K,P<!N&",`"NAC`';@%``/H7B`@M2AP
M!;H?0`2T%D`:B@%`';LQ,`*T#H`"B2DP'K0!0!J*%T`$B`Z``K,Q,!N*"4`"
MAAE``[H%0`7J7B`8M2DP!888P`&T%D`:M@;``X<P<`*T#H`"@RAP'K8&P!J&
M$,`!@@[``K,P<!N&",`"BAC`!;8%@`.U*'`%BAE`!+060!JX!P`%BS$P`K0.
M@`*)*3`>N`<`&ILH<!Z*$4`$B@E``H@/``*S,3`;AAE``[4I,`6&&,`!M!9`
M&KH'0`.','`"@@Z``H('0`&Z$,`-VE^DK[H/0`*""$`"N`7`!8H?0`6U,'`;
MBAE`!(<H<`6V!L`%AA:``Z8$P!WT7Z.OBS$P`H8(P`*)*3`>A@;``XH10`2&
M",`"B2CP!8H)0`*Z&4`=L@:`!;<P\!NZ'T`!N`<`';86P`2[,'`"B2AP'H(.
MP`+V7Z2/B!=`!(('``&("0`"@@A``HH9``6Z!L`$MS!P&[@90`.+*'`%I@3`
M'+DP\`*V%L`%BRCP'H8.P`**%P`%A@3``_A?I)>*"4`"A@C``N9?I,>(&4`$
MM@<`!;4P\!NX&0`!B2CP!;(&0!RY,'`"M!:`!(DH<!Z"#H`"B!<`!((&0`&(
M"0`"@@A``HH9``6X`D`$LS!P&[090`.+*'`%M`=`&KLP\`*R%D`%BRCP'H8.
M0`**%T`%A@:``XH)0`*&",`"B!E`!+0#``6S,/`;NAD``8DH\`6V!L`=NS!P
M`K(60`2)*'`>@@Y``H@70`2"!L`!B`D``H((0`**&0`%M@-`!+,P<!NZ&4`#
MBRAP!;@'`!V[,/`"LA9`!8LH\!Z&#D`"BA=`!88'``.*"4`"A@C``H@90`2X
M!``%LS#P&[H9``&)*/`%M`:`';LP<`*R%D`$B2AP'H(.0`*(%T`$@@:``8@)
M``*""$`"BAD`!;($@`2U,'`;NAE``XLH<`6V!L`=NS#P`K06@`6+*/`>A@Z`
M`HH70`6&!L`#B@E``H8(P`*(&4`$M@3`!;4P\!NZ&0`!B2CP!;@'`!V[,'`"
MM!:`!(DH<!Z"#H`"B!=`!(('``&("0`"@@A``HH9``6Z`0`4N!E``[H/0`*+
M*'`%L@9`'+4P<!NY,/`"M!:`!8LH\!ZT#H`"BA<`!88&0!J&",`"B@E``K@9
M0`26`,`+B3#P&[@?``&'*/`%M@;`'(@1``.*`4`5N3!P`H@)``*#*'`>B`;`
M!((7``&("0`"@@A``H@!``^"`$`*A@K``H@)``*""$`"R'8``(0)0`+&=B`(
MPG8@$,1V(!CZ=B`@@<_@"`$````!````G>._4+H0`!@"QT`DL!`@``,`"#/@
M6&&X`L0`(`$```#"3T``A!A@/8"@``*$0"``@*```8)`(`"`B(`!$D@`&;00
M(`#X7````L<`%+`0(`"U/J``MA``$)`0`!R2$``=0`0C*)00`!J`HB``,D@`
M![8&X`C"3P`:@*!@/2)``!:V)L`0M@;@"/A>P``*_S_TD!``'+`0(`"!S^`(
M`0```((0`!W$2&`!M`!@`888H#V`H``#AD`@`("@``*$0"``@(C``A)/__B"
M$``:$&__WK0F@!VT!J`!MS[P`_8F0`"!S^`(D`,`"C!H``8!`````0````$`
M```!`````0```)WCOT"0$``8?___OI('I_N!Q^`(D>@`"`$````!````G>._
M0#L`"#.0$``8?___M9('I_L"P@`1QD>G^\A?8;B'*/`#@@$``\188`@"\+_W
MQ'$``\188!#$<&`("OB__H(`8`B0$``8?___II('I_L*^C_SQD>G^X'/X`@!
M````G>._4$`$)%^0$"``0`0C[=`"``!`!"(3`0```,):``"0$"``0`0D5_I8
M8`A`!"/ET`(``$`$(G,!````^`H``$`$)%"0$"``T`(``$`$(]VX#R!_0`0B
M<P$```#"6@``D!`@`,)88""#,'`W@RA@![@7``%`!"1#^#=@`D`$(]'0`@``
M0`0A]P$```#"6@``D!`@`$`$)#OZ6&`(0`0CR=`"```3``07E!`@`$`$(^V2
M$F$XT'=@*$`$)#*0$"``0`0CP-`"``!`!"'F`0```,):``"0$"``0`0D*OI8
M8`A`!".XT`(``$`$(BX!````PEH``)`0(`!`!"0BPG=@,$`$([#0`@``0`0A
MU@$```#"6@``D!`@`$`$)!KZ6&`(0`0CJ-`"``!`!"-^`0```,1:```"P(`*
M@A`@`$`$)!&0$"``0`0CG]`"``!`!"-U`0```,):``#"6&"HPG=@.$`$)`B0
M$"``0`0CEM`"``!`!"&\`0```,):``"0$"``PEA@"$`$(__`<&!`0`0CC=`"
M``!`!"&S`0```,):``"0$"``PEA@"$`$(_;`<&`@0`0CA-`"``!`!"&J`0``
M`,):``"0$"``0`0C[OI88`A`!"-\T`(``$`$(\(!````PEH``,)W8$B!S^`(
M`0```#!H``0!`````0````$```"=X[[``L8`4@$```#"3@``@*!@``)(`#V0
M$``80`0CR3<`!!>Z$``(MA;@B#,``#P"P@`V-0``$$`$(MJ0$``=@A``")`0
M`!@"P$`LH`!@$\0(8!.`H*`N(D@`+L0(8!1`!"/H`0```+@0``A`!"/ED!``
M$)`"`!R0`B`"0`0AV9$Z(`"6$``;F!``&)H0`!"2$"`!E!`__T`$(WJX$``(
MDA``')0'IV]`!"'&D!`@`X"B/_\"0``'D!``',('IX>""$`9@*!`&@)``!T!
M````0`0C+`$```!`!"-RD!``'$`$(K"0$``=@A``")`0`!@*^'_8H`!@$T`$
M(8*0$``=0`0AX)`0`!B!S^`(`0```("@H``"3__)@*"@+A)/_]$!````P@A@
M%8"@8``"3__#`0```!!O_\L!````?___L0$````0;__E`0```('/X`@!````
M,&@``P$````!````G>._4)`0(`!`!".&NA`@`$`$(Q30`@``0`0B\@$```"4
M$``(DA``&$`$(B:0$"`#@*(@``)```20$"``@<_@")$[8`!`!"-W.0``/$`$
M(P70`@``0`0BXP$```#$`B`8`P``$(0(@!R`H(`!(D``#I`0`!A`!"-KD!`@
M`$`$(OG0`@``0`0BUP$```#"`B`8N`A`'`,``"B`IP`!$D__Z)`0`!A`!",_
MDA`@`H"@``BZ8#__@<_@")$[8``!````G>._0,).0`""&&`]@*```8)@/_^R
M!D`!0`0C<I`0`!FX$``(D@>G^W___HZ0$``8`L(`8;H0``A`!"-J`0```(4W
M(`"`H@`"&F@`38(0(`#Z!Z?[-P`(,\).``"$&&`]@*```H1`(`"`H``!@D`@
M`("(@`$"0``-AA``&((0`!C$2&`!A@!@`8@8H#V`H``$B$`@`("@``*$0"``
M@(D``A)/__B"$``#]E[AN+LW8`"X)P`8NR]P`[@'(`*&!P`#0`0A0)$PX`#0
M=L`=`L(`*H(0/__"!Z?[!0`(,\98H;B#*'`#Q`X``,)8P`&)**`8B3D@&,0H
M0`"`H2```D``$X80``&`H2`]`D``$800(#T0:``%L`8@`8"@H#T"0``,A!`@
M/<0.``"&`&`!L`8@`8DHH!C$*&`!A3D@&("@H``23__V@A```X00(#V"$"``
MQ"C``,0.0`&*`,`!@@!@`8DHH!B`H2``$D__^\0I8`&"$"``@<_@")$X8`#$
M#D`!Q"]``84HH!B`H*```D?_^8(`8`'$#D`!Q"]``84HH!B`H*``$D__]H(`
M8`$0;__R@A`@`#<`"#.2$"`0XE[AN,)<0``"P$`*NA`@`((0`!&"`&`(Q%A`
M``KXO_ZZ!V`!D@=@`I,Z8`"3*G`#`P`(,\0`8>B`H*```D@`#H00(`&A/V``
M0`0AIY`0`!'0=N&XM!``"`+R/]B"$#__H`0@`:$L,`/`=H`0$&__C/HGI_N0
M$``)0`0@X\0@8>BT$``(`O(_S8(0/_^A/V``DA``$4`$(3R5+#`#$&__\?1V
MX;B=X[]0D!`@`$`$(KXS``07T`(``#4`"#(W``07LA9@D$`$(DBT%J`@L!``
M"!"$(IV7[N"P,&@``P$````!````G>._4)`0(`!`!"*N-P`$%]`"``"V%N$X
M,P`$%S4`!!5`!"(XNA`@`'___^:R%F#`0`0BI)`0(`#0`@``M!:A`$`$(C"X
M$``;$(0AEI'H``@P:``$`0````$````!`````P``"((8?S"=XX`!PEG@*,)W
MI_>"$"``0`0APCL```B$!Z?_NA]_Z!<`!!>Z`(`=%0`0`1L`!!>2$"`!F3H@
M`)82X-B0$``=FA-@Z)4RL`I`!")$L!`@`("B(``&0``4D!``'14```2"!Z?_
MNAJ_\+H`0!U`!"$3DA``';B2(``&0``+D`<@`4`$((Z1.B```L(`![`0``BY
M/R``DA``'4`$(HB4$``<P"X`',)?I_?$6>`H@AA``H00(``*P$`$`0```('/
MX`@!````0`0AM0$````!`````0````$```""$\``$&__QP$````P:``%`0``
M``$````!`````0```)WCL``1``07G`._,)`2(/C"6>`HPG>G]X(0(`!___W1
M`0```+H0``B2$"`O0`0AI9`0`!@BP@`.D!``&!$`!!>2$``8?__^[Y`2(0C"
M7Z?WQ%G@*((80`*$$"``"L!`:@$```"!S^`(`0```$`$(ETU``07H!``")(6
MH1A`!"")D!``&0+R/^ZD$``(.0``!(0'I_^X'S_X(P`$%S,`!!<W``07N`"`
M'*(482"R%F$HM!:A&,1,@`""%N#P@*"@``+'0`BE9$`!D!``'4`$(162$``2
M@*(@``)``#B0$"``0`0B0)`0`!*#.B``A`2``<1(O_^`H*`O$D``"8(`?_^"
M!(`!P"A``((`?__$2$``@*"@+P)/__R0`C__D`(@`9`"`!"`HB__%$?_Q9(0
M(`$5```$\'.HKY80`!&8$``2FA``&4`$(<>0$``<0`0B!9`0(`!`!"&3T`(`
M`$`$(7$!````E!``")(0`!Q`!"`-D!`@`X"B(``R2``0D!`@`$`$(?B0$"``
M0`0AAM`"``!`!"%D`0```,0"(!@#```\A`B``0,``""`H(`!`D``"9`0`!R0
M$"``0`0@.I(0`!H*^C^]I!``"!!O_YX1``070`0AQ)(0(`&`HB``,D__]Y`0
M(``1``07DA``''___H60$B$(0`0@PY`0`!P0;_^4L!``"$`$(2<!`````0``
M`#!H``0!`````0````$```#$"@``A2B@&("@H``"0``+@@(@`84XH!B`H*`O
MD61``8(`8`'$"'__A2B@&("@H``23__ZA3B@&('#X`@!````G>._4`+&`#0!
M````PDX``("@8``"2``P`0```$`$(=F0$``8D`(__X0&``B`I@`"&F``2H(0
M``+"3@`(@*!@+R)(``B"`+__$&@`1H(0``*`H.`O$D``+(00``&"`+__@*!`
M&#)O__O&2+__A!```8"@@!@B8``JPDB``)0`O_^`I@`*.F``!Y0B@!C"2+__
M@*!@+P)/__J$$``*E"*`&!<```2"`J`"@*!`"QA@``B0$"``.P`(,Y(0`!B0
M%V'P0`0?8)0"H`&0%V'P@<?@")'H``A`!!^CD!`@`@+R/_P!`````P``"X(0
M8@#",@``@<?@")'H``B`H.`O`D?_W8(0``*$`'__@*8``BIO__O&2'__$&__
MV("@@!B`H&`O`D``!#$`!!<0A"!>D>XA*$`$'XR0$"`"@A``"`+P?^20$"``
M!0``"Y`0``&$$*(`$&__W\0P0``0;__&A!```1!O_^J$`'__,&@`!@$````!
M`````0````$````!````G>._(`,`!!@1``07REA@$)`2(3`[``07R%A@&#<`
M!!<Y``07QEA@(#4`!!?$6&`HPA!@,/)9X"CR=Z?WLA`@`,IWI\_(=Z?7QG>G
MW\1WI^=___S4PC>G[Q$`!!=___S1D!(A0!$`!!=___S.D!(A2!$`!!=___S+
MD!(A6'___,F0%V%@$0`$%W___,:0$B%P?__\Q)`6X/A___S"D!<A@'___,"0
M%J&0$0`$%W___+V0$B&@$0`$%W___+J0$B$($0`$%W___+>0$B&P$0`$%W__
M_+20$B'`$0`$%W___*F0$B'0`L(`!)(0``A___W-D!:AD!$`!!=___RBD!(A
MZ"+"``<1``07DA``"!$`!!=___W$D!(B`!$`!!=___R9D!(B$`+"`!"2$``(
M?__]O9`6X/@3``07D!=A8'___;F2$F)(PE^G]\19X"B"&$`"A!`@``K`0!H!
M````@<_@"`$````1``07?__\AI`2(B`"P@`&DA``"'___:J0%R&`$&__[A,`
M!!<3``07D`>GX)(28CA`!!][E!`@"H"B(``R3__F$P`$%Y`7(8!___V=D@>G
MZA!O_^$3``070`0@00$````!````,&@`!@$````!`````0````$````!````
MG>._4#L`"#/P!V&D@*8__P)```2Q/B``@<_@"`$````1``07L!`@`'___%Z0
M$B&`(L(`"O`G8:3"2@``@*!@`")(``;P)V&D@AA@,("@``&P0"``\"=AI('/
MX`B1.B``G>._4$`$'I>P$"``0`0>?9$R(``JR@`"\%H``('/X`@!````,&@`
M!P$````!`````0````$````!`````0```)WCOQ`#``07.P`$%X(08F#"=Z?7
M-0`$%P,`!!<W``07@A!B:,)WI]^Z%V)0`P`$%_IWI\^X!Z?7@A!B<,)WI^>T
M%J$@`P`$%[86X1B"$&)XPG>G[P,`!!>"$&$X$&@`"\)WI_=`!!Z?`0````+"
M`!H!````^E\``,)/0`"`H&```D``$[@'(`A___P>D!``':`0``@"P@`&DA``
M&,)*``"`H&``$D__\`$```"0$``=?__]/)(0`!CZ7P``PD]``("@8``23__Q
MN`<@"('/X`@!````0`0@JY`0`!BR$``(0`0@J)`0`!"0!D`(0`0>G9`"(`+@
M<ZBODA`@`900/_^6$``:F!``&)H0`!M`!"`]LA``")`0`!U___TBDA``&1!O
M_];Z7P``,&@`!@$````!`````0````$````!`````P``(((8?>"=XX`!A`>G
M_PD``""&$``"MAD^^+(0``.*&3[(-0`$%X(`@`7Z6>`H^G>G][H0(`"$`(`;
MM!:BH/1V0!LW``07.P`$%[86XJCV<*`(NA=A.#<`!!?Z<*`8B!D_&+86X/#V
M<*`0!0`$%X00HK#$<&`(A@#`!`4`!!?Z<&`H.0`$%X00HKC$<&`0-0`$%P4`
M!!<W``07^G#@$(00HL#$<&`8D!<@^`4`!!>T%J(`]'9`!800HLC$<&`@`P`$
M%X(08M"V%N*0PG#@"'__^[SV=D`$`L(`!K(0``C"2@``@*!@`!)``.0!````
M?___9`$````"P@#FI!``",),@`"`H&```D``$O8,@`!`!![T`0```((0`!*&
M$"!?MR[P.,1:``"W/O`WQ!"`&X"(J``B:``"QBA``((`8`'$2$``@*"@`!)/
M__;V"$``(0``(+(0(`&0$``:$&@`"Z`</LB#/F``A@>G_X,H<`."`,`!T%A`
M$,)*``"`H&```D``F+(&8`%___N.`0````+R/_6V$``(?__\@@$```"`HB``
M`D__\8,^8`!`!![MD!``&P+Z/^RV$``(D!``&T`$("`C``07LA``"$`$(!V0
M$``2L@(`&;(&9`2S/F``0`0>$)`0`!FT$``(0`0>#9`0`!GD<ZBW%P`$%P,`
M!!>"$&+PDA`@`<)SJ*^4$#__EA+BX)@0`!N:%&$H0`0?J;(0``B0$``90`0?
M#I(0(>T1``07?__[8Y`2(G`BP@`)]EX``$`$'L?V7@``DA``"'___820$``;
M`L(`IK80``A`!!_XD!``&X"B(`,$2``3H!``")$Z(``3``07D`(__)(28OA`
M!!Z_D`;`"("B(``22``*@*0@!`)``9&"!#_\@SA@`((&P`'"2'__@*!@+R)`
M`8SP7B`(?__^V@$```"`HB``$D@`"1,`!!>0$``;0`0?C)(0(`"`HB``,D``
MAZ$Z(``3``07$0`$%Y(28DA___Q<D!(A@$`$'N(A``07^G.HMY$Z(``7``07
MT'.HKY(0(`&4$#__D!``&I82XR"8$``9FA1A*$`$'V:V$"``H!0C,!!H`!:P
M%&$H0`0>L0$```#"`@``@*!@$1)``!8!````0`0>R[8&X`'Z<ZB_D3H@`-!S
MJ*^#/N``D!``&L)SJ+>2$"`!E!`__Y80`!"8$``90`0?3YH0`!B0$``:0`0>
MM)(0(>V`HC__`D__Z`$```!`!!]/D!``&9`7(/A___PLDA``&G___L*0$``:
MPE^G]\99X"B"&$`#AA`@``K`08>P$``:@<_@"`$````S```@@@>G_[(>?OCV
M6$`9PD[``("@8``22``,M!`@`1!O_V^V$"``A`>G_X,H<`."`(`!]EA`&<).
MP`"`H&```D``%+0&H`%___O>D!``&X"B(``"3__U@SZ@`$`$'DF0$``;"O(_
M7K80``B#/J``A`>G_X,H<`."`(`!]EA`&<).P`"`H&``$D__\+0&H`$0;_]3
MMA`@`'___I(!````0`0>.)`0`!D0;__.M!``""$``""R$"`!D!``&Z`</QA_
M__K(`0````+"``>#/F``0`0>+`$````*\C\2I!``"(,^8`"$!Z?_@RAP`X(`
M@`'06$`0PDH``("@8``23__QL@9@`24`!!<0;_\:I!2BF!!O_USV7@``DA`_
M[I00(`)`!!UHD!``$#$``""&!Z?_L!X_,)`0`!"V`,`8E!`@!D`$'M"2$``;
MA`>G_\((@!B`H&``$D``!Y`0`!#"#N`!@*!@0R)``0C"#N`"D!``$)(0(`"4
M$"``0`0=4C$``"#`=Z=7`QG12+`>/S#`=Z=?@A!C`<)WIR^&!Z?_`SOS:J00
M/__`)Z>G@A!CB<)WIS>P`,`8`R8NMZ80($"E-+`@@A!@_L)WIS\#!`R5@A!@
M=L)WIT<#,/2X@A!A\,)WIT^0$``0DA``&$`$'J85```@MI(@``1``%3*7Z=7
MGS[@`(80(`")*_`#Q%^G7ZP0`!C"!Z>GGS/P'8@!``6("0`2R'>G5X"A0`2'
M9S`!@*!@`(<PX`"$`(`#A`"`#P)(`!7$=Z=?J"3``80'IV>#.&``@*;`%*ED
M@!N0`(`!DA``&*T](`!`!![WE!``%L('IZ>"!0`!@*!@0!)/_]K")Z>GD`>G
M+[8FP!1___/&K`8`%H"FX#\$0``?!P``'K8&_\"#-N`&AAC^NX8`P!ZJ!:!`
MKS!@`,(@P`"H$``6@RWP!JH%0`&2$``4E!`@0)`'IV=`!![<J`4@0'__\[*0
M!Z<O@*4`%1)O__F2$``4!P``'JX%X`&O+?`&AAC^NX8`P!ZL!8`7Q@#``(,H
MX`:V)L`!E3[@`)(0`!:6$"!(0`0=(9`'IV?V)Z>GD!``$)(0`!A`!!Y4%0``
M(+:2(``43_^PRE^G5T`$')>0$``0X%^G5X8'I__D7Z=?@S0P`X((8#^%.&``
MD`!@`80`P`*&$#^`@*(@.!1``''&*+]HA!`@-Y(0(`"1.B``@B"``94X8`"$
M!Z<OD`"`"$`$'?*0`B`X@S2P&,(OIY^0!Z<O@S2P$,(OIZ"V$"``A30P&.0O
MIZ*P!Z>O@S0P$.`OIZ;$+Z>CH30P",(OIZ2E-+`(X"^GI2$`!!?D+Z>A?__S
M;J`4(QC*7Z<OR%^G-\9?IS^?,7`8Q%^G1YLQ<!"8$``/PE^G3Y,Q<`B5,3`8
MWB^GWY<Q,!#:+Z?@GS#P&,HOI^*;,3`(TB^GX8LP\!#4+Z?CDS#P"-8OI^25
M,+`8VB^GY9<PL!#(+Z?FFS"P"-XOI^?*+Z?HGS!P&(LP<!#2+Z?IB3!P",8O
MI^K4+Z?KUB^G[-HOI^W$+Z?NWB^G[\HOI_#(+Z?Q$&@``\(OI_+8#L`!D`;`
M&Y(0(`&0!@`(E!`__Y80`!!`!!X,F`L@_[8&X`&`IN`4$F__]H('I]\7``07
MD!``&L`OI]>2$"`!E!`___!SJ*^6$N,(F!``&?ISJ+=`!!W]FA1A*!!O_K0!
M````\%X@"`+V/G8!````0`0>5I`0`!B`HB`#"&_^<9`"/_P3``07D`8`"$`$
M'1^2$F,`@*(@`!!O_FJW9$`8E!`@/Y(0(`"1.B``E"*``94ZH`""!Z<OD`!`
M"$`$'8.0`B`X?__S$9`'IR_`=Z=GP'>G;\!WIW?`=Z=_P'>GA\!WIX\0;_^)
MP'>GEX"@8$$23_[ZD!``$,(.X`.`H&!#$D_^]Y(0(`#"#N`$@*!@2!)/_O24
M$"``P@[@!8"@8$423_[P`0```)00(`)`!!P_DA`_QI(0`!N0$``00`0=JY00
M("GV<ZBO%P`$%Y`0`!KZ<ZBWDA`@`900/_^6$N,(F!``&4`$';F:%&$H$&_^
M<`$```!`!!U%`0````$````!`````0```)WCL`#"6>`HPG>G]X(0(`"<`[]`
M0`0=ZY`0(`!`!!UYT`(``$`$')\!````@A`@`<(J```1``07?__Y8I`2(6`"
MP@`&`0```,)*``"`H&`Q(D``HL)*(`%___QZ`0```$`$'=B0$"``0`0=9M`"
M```3``07E!`@`9(28TA`!!PQEA`@"P+"`#HS``@WQ%H@$+H0(`#"!F'X@*!@
M`01``##T6*`HN!`@"!!H``XQ``@WTEA@$$`$'+.0$``;@*(@`!)``"?"!F'X
MN@=@`<(&8?B$!V`!@*!``@1``"&X!R`(0`0=N)`0(`!`!!U&T`(``)(0`!J6
M$"``0`0<ZI4_8``"P@`6H!``",):``#&7B'PQ`!@#("(I``2;__F]EC`'$`$
M':B0$"``0`0=-M`"``#27```E!`@`$`$'=*6$"`"DA``"$`$'(^0$``;@*(@
M`")/_]^Z!V`!P@9A^(0`?_^`H(`=`D``8H"@8`%`!!V5D!`@`$`$'2/0`@``
M$P`$%Y00(`&2$F-00`0;[I80(`0"P@`2NA``"$`$'8J0$"``0`0=&-`"``#"
M7V`0%0`$%Y02HUA`!!OKTEA``,)?8!#"6$``Q`!@#`,`$`"`B(`!$D``60$`
M``!`!!UZD!`@`$`$'0C0`@``$P`$%Y00(`&2$F-@0`0;TY80(`0"P@`/NA``
M"!$`!!=___CND!(A"`+"`%*X$``(0`0=:I`0(`!`!!SXT`(``,)?8!"4$``<
M0`0;S-)80`"0$"``0`0=83<`"#=`!!SOT`(``$`$'!4!````P"H``$`$'5J0
M$"``0`0<Z-`"``!`!!UF`0```,!R```1``07?__XTI`2(/@"P@!YT';B`$`$
M'':2$"'M@AH@$8"@``&$0"``@*``"()`(`"`B(`!`D``!("B/_\20`!FESH@
M`,)?I_?$6>`H@AA``H00(``*P$!>`0```('/X`@!````@*!@``)/_V$!````
M$&__70$````$1_^@`0```#D`"#>Z$"`!N!<A^)`0(`!`!!TON@=@`4`$'+W0
M`@``0`0;@Y(0`!K"!P``@*!`'31/__B0$"``$&__D`$```!`!!TCD!`@`$`$
M'+'0`@``PE]@$$`$'&;26$``$&__H@$```!`!!T:.0``!-`"``!`!!RGN!\_
M^(8'I_\#``@WQ%]@$,)88?"X`,`<$0`$%Y`2(VB2$``<]%B``)00+_]`!!NC
M\EA``("B(``$0``?@@(__X4X8`#$3P`"@*"@`!)(``8W```$@*!@``)``!<!
M````D!```8('I_^V'O_XDA`@+[DZ(`"V`$`;E!``'$`$&Z>0$``;`L(`#`$`
M``!`!!SSD!`@`$`$'('0`@``DA``&I00`!M`!!P-EA``'!!O_XJ0$"``0`0<
MZ9`0(`!`!!QWT`(``)(0`!I`!!M,E!``&1!O_X&0$"``0`0<,`$````#``@W
MU%[B`,)88?`1``07D!(CJ$`$'''26$``.0`(-W___&;07R'PPE]@$-!VX@#"
M6$``Q`!@#("(I``"8``3`0```-!88!!`!!Q4TE\A\,)?8!#$7R'PPEA``/A8
M@`#$`&`,@(BD``)@`!.V$``(U%A@$!$`!!>2$``<ES[@`$`$'%:0$B-X0`0<
MO)`0(`!`!!Q*T`(``,)?8!"4$"``EA`@`D`$'.726$``$&__YP$```!`!!RQ
MD!`@`$`$'#_0`@``PE]@$)00(`"6$"`"0`0<VM)80``0;__GE!``"#!H``8!
M`````0````$````!`````0```)WCOU!___K?D!``&,0*``"%**`8@*"@``)`
M``RZ$``(@@(@`84XH!B`H*`ONV1``8(`8`'$"'__A2B@&("@H``23__ZA3B@
M&'__^Z8!````@*(@``)```\!`````L8`#0$```#"3@``@*!@``)```D!````
M$P`$%Y`0`!U`!!IYDA)B\("G0`@"8``$`0```('/X`@!````$&_XFH'H``"=
MX[]0D!`@`$`$''8S``0.T`(``+00(`!`!!P"LA9C0$`$&Q"2$#__0`0<;I`0
M(`!`!!O\T`(``!"$')*1Z``(G>._4`,`!!DO``09?__Q$ZX%XUR"&'WX@@7`
M`?980`"W>$0`$(0:CX'H```P:``%`0````$````!`````0```)WCOU`W````
M.0```"\`!!E___$"K@7C&+8>_7A___`QN!\]>+8%P!NX!<`<MB;`'+<^\`,"
MQL`+NA`@`,)?``"0$``8DA``&900`!J?P$``N@=@`8"G0!L2;__YN`<@"('/
MX`@!````,&@`!@$````!`````0````$````!````@</@"`$````P:``&`0``
M``$````!`````0````$```"=X[]0.P`(,,)?8`"`H'__`F``";H78`BZ!W_X
MG\!```$```#"7W_X@*!__Q)O__RZ!W_X@<_@"`$````!````G>._4('/X`@!
M````,&@`!0$````!`````0````$```"=X[]0?__PQP$```"!S^`(`0``````
M`````@`!````````````````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(``````'!E<FQX<VDN8P````````!);G1E<FYA;',Z.E!!4CHZ
M0D]/5``````O<')O8R\E:2\E<P``````97AE```````N`````````%!!4E]4
M14U0``````````!005)?4%)/1TY!344`````.@`````````E<R5S)7,``"\`
M````````4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?
M0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!0
M05)?05)'0P``````````4$%27T%21U9?,````````%!!4E]'3$]"04Q?1$5"
M54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(`
M``````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````
M4$%27T-,14%./0```````#$`````````3$1?3$E"4D%265]0051(`$Q)0E!!
M5$@`3$E"4D%265]0051(`````$193$1?3$E"4D%265]0051(`````````%53
M15(`````4UE35$5-``!#.EQ414U0`"]T;7``````5$U01$E2``!414U01$E2
M`%1%35``````5$U0``````!54T523D%-10``````````)7,E<R5S)7,`````
M`````'!A<BT`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E
M,#)X`````"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````````
M``!!4D=6`````!@`````````<&5R;``````P`````````"]P<F]C+W-E;&8O
M97AE```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I
M=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```"5S
M````````+64````````M+0```````%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@```````````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P[
M"@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@
M870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`[
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE
M.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@
M(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B
M96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@
M(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H
M:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T
M;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA
M=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@
M(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N
M(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M
M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI
M<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN
M9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@
M(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%
M(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^
M("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*
M"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<
M)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I
M"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE
M;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T
M;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A
M=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I
M"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"
M14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET
M7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6
M>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%2
M1U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@
M)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6
M*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*
M("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX
M("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@
M*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I
M;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[
M>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L
M(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@
M("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN
M(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@
M9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@
M("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@
M("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@
M("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B
M=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@
M("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D
M('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D
M14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T
M<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@
M)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@
M("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL
M;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@
M/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@
M("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@
M("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@
M("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@
M("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@
M("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E
M96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M
M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[
M8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E
M='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)
M3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@
M("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@
M("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M
M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S
M="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L
M97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R
M97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I
M=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C
M97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D
M;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O
M;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE
M<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M
M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@
M("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A
M<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R
M"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N
M86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B
M+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D
M92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E
M;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE
M;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O
M7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@
M('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@
M(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@
M("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD
M;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@
M("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A
M8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI
M9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C
M;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%
M35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@
M("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8
M("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T
M(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D
M("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@
M("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@
M("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@
M("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@
M("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*
M("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@
M("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$[
M"B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P
M;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`[
M"B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT
M.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI
M("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*
M("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H
M+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*
M("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD
M;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC
M*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`
M:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T
M:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*
M("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET
M92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&
M:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@
M("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O
M0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI
M<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T
M:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G
M:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L
M"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F
M:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S
M>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R
M('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@
M("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M
M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@
M(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B
M+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0[
M"B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@
M("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@
M("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E
M<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O
M=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E
M<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@
M("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D
M8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO
M=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@
M("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D
M8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I
M9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;
M.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O
M<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^
M861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E
M.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*
M?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A
M8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,[
M"@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!
M4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@
M<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@
M1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@
M('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q
M*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@
M("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@
M("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M
M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA
M;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT
M<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@
M("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN
M8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@
M("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN
M<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]
M?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@
M"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@[
M"B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*
M("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*
M("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@
M(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q
M=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U
M:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I
M<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@
M<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(&%T
M=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@
M>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C
M;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A
M;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E
M;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@
M("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@
M("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@
M("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I
M9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@
M("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@
M("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M
M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@
M("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.
M5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I
M*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N
M86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@
M("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L
M("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T
M,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@
M("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@
M("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X
M(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@
M("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@
M("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@
M("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@
M("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*
M"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@
M(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE
M*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@
M("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE
M;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@
M)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU
M;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@
M("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN
M;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S
M86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O
M9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.
M5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N
M*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R
M;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@
M("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@[
M"B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X
M97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@
M("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@
M("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I
M9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@
M("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@
M("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E
M=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D
M<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?
M9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@
M>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@
M("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@
M("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@
M("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L
M971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@
M("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R
M;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@
M)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT
M(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@
M0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE
M8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`
M24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD[
M"@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE
M<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q
M*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@
M)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q
M,@H*7U]%3D1?7PH`````````<&%R+G!L```!&P,[````Y````!O__V!P```#
M*/__9%````$`__]]D````1C__WZ0```!,/__?K````%(__]_$````6#__X$0
M```!>/__@G````&0__^#,````:C__X60```!P/__A=````'8__^&,````?#_
M_X<0```""/__AS````(@__^)4````CC__XF0```"4/__BQ````)H__^,\```
M`H#__XU0```"F/__C9````*P__^.T````LC__YC0```"X/__GA````+X__^>
ML````Q#__Y[P```#0/__GS````-8__^?L````W``````````%``````!>E(`
M!'@/`1L,#O\/````````%````!S__V-(```9/`!!#1XM"0\?````%````#3_
M_WQP````Z`!!#1XM"0\?````%````$S__WU8````&`!!#1XM"0\?````%```
M`&3__WU@````8`!!#1XM"0\?````%````'S__WVH```!\`!!#1XM"0\?````
M%````)3__W^0```!5`!!#1XM"0\?````%````*S__X#8````O`!!#1XM"0\?
M````%````,3__X&````"8`!!#1XM"0\?````%````-S__X/(````-`!!#1XM
M"0\?````%````/3__X/P````4`!!#1XM"0\?````%````0S__X0X````V`!#
M#1XM"0\?````%````23__X4`````#```````````````%````3S__X4(```"
M$`!!#1XM"0\?````%````53__X<0````0```````````````%````6S__X<X
M```!:`!!#1XM"0\?````%````83__XB@```!R`!!#1XM"0\?````%````9S_
M_XIH````8`!!#1XM"0\?````%````;3__XJP````)`!!#1XM"0\?````%```
M`<S__XK8```!*`!!#1XM"0\?````%````>3__XP````)^`!##1XM"0\?````
M%````?S__Y7H```%*`!!#1XM"0\?````%````A3__YL0````H`!!#1XM"0\?
M````%````BS__YN8````0`!!#1XM"0\?````%````D3__UU````"G`!!#1XM
M"0\?````%````ES__YNH````+`!!#1XM"0\?````%````G3__YO0````:`!!
M#1XM"0\?````%````HS__YPX````"```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M```````````````````!``````````$``````````0````````*Y````````
M``$````````"R``````````!`````````M0``````````0````````+?````
M``````$````````"Z0`````````!`````````O<``````````0````````,$
M``````````$````````#4P`````````/````````!+H`````````'0``````
M``2Z``````````P``````!`<0``````````-```````07&``````;__^]0``
M````$`)@``````````4``````!`."``````````&```````0!2``````````
M"@````````44``````````L`````````&``````````5````````````````
M`````P``````(,,```````````(````````'F``````````4``````````<`
M````````%P``````$!2H``````````<``````!`48``````````(````````
M!^``````````"0`````````8`````'````$``````````0````!P```!````
M``````(`````<````0`````````#`````&____X``````!`3X`````!O____
M``````````(`````;___\```````$!,<````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````@P"@`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````#``"`,&__YP$````!`````0````$````!`````0````,``*`P
M;__?`0````$````!`````0````$````!`````P``P#!O_]<!`````0````$`
M```!`````0````$````#``#@,&__SP$````!`````0````$````!`````0``
M``,``0`P;__'`0````$````!`````0````$````!`````P`!(#!O_[\!````
M`0````$````!`````0````$````#``%`,&__MP$````!`````0````$````!
M`````0````,``6`P;_^O`0````$````!`````0````$````!`````P`!@#!O
M_Z<!`````0````$````!`````0````$````#``&@,&__GP$````!`````0``
M``$````!`````0````,``<`P;_^7`0````$````!`````0````$````!````
M`P`!X#!O_X\!`````0````$````!`````0````$````#``(`,&__AP$````!
M`````0````$````!`````0````,``B`P;_]_`0````$````!`````0````$`
M```!`````P`"0#!O_W<!`````0````$````!`````0````$````#``)@,&__
M;P$````!`````0````$````!`````0````,``H`P;_]G`0````$````!````
M`0````$````!`````P`"H#!O_U\!`````0````$````!`````0````$````#
M``+`,&__5P$````!`````0````$````!`````0````,``N`P;_]/`0````$`
M```!`````0````$````!`````P`#`#!O_T<!`````0````$````!`````0``
M``$````#``,@,&__/P$````!`````0````$````!`````0````,``T`P;_\W
M`0````$````!`````0````$````!`````P`#8#!O_R\!`````0````$````!
M`````0````$````#``.`,&__)P$````!`````0````$````!`````0````,`
M`Z`P;_\?`0````$````!`````0````$````!`````P`#P#!O_Q<!`````0``
M``$````!`````0````$````#``/@,&__#P$````!`````0````$````!````
M`0````,`!``P;_\'`0````$````!`````0````$````!`````P`$(#!O_O\!
M`````0````$````!`````0````$````#``1`,&_^]P$````!`````0````$`
M```!`````0````,`!&`P;_[O`0````$````!`````0````$````!`````P`$
M@#!O_N<!`````0````$````!`````0````$````#``2@,&_^WP$````!````
M`0````$````!`````0````,`!,`P;_[7`0````$````!`````0````$````!
M`````P`$X#!O_L\!`````0````$````!`````0````$````#``4`,&_^QP$`
M```!`````0````$````!`````0````,`!2`P;_Z_`0````$````!`````0``
M``$````!`````P`%0#!O_K<!`````0````$````!`````0````$````#``5@
M,&_^KP$````!`````0````$````!`````0````,`!8`P;_ZG`0````$````!
M`````0````$````!`````P`%H#!O_I\!`````0````$````!`````0````$`
M```#``7`,&_^EP$````!`````0````$````!`````0````,`!>`P;_Z/`0``
M``$````!`````0````$````!`````P`&`#!O_H<!`````0````$````!````
M`0````$````#``8@,&_^?P$````!`````0````$````!`````0````,`!D`P
M;_YW`0````$````!`````0````$````!`````P`&8#!O_F\!`````0````$`
M```!`````0````$````#``:`,&_^9P$````!`````0````$````!`````0``
M``,`!J`P;_Y?`0````$````!`````0````$````!`````P`&P#!O_E<!````
M`0````$````!`````0````$````#``;@,&_^3P$````!`````0````$````!
M`````0````,`!P`P;_Y'`0````$````!`````0````$````!`````P`'(#!O
M_C\!`````0````$````!`````0````$````#``=`,&_^-P$````!`````0``
M``$````!`````0````,`!V`P;_XO`0````$````!`````0````$````!````
M`P`'@#!O_B<!`````0````$````!`````0````$````#``>@,&_^'P$````!
M`````0````$````!`````0````,`!\`P;_X7`0````$````!`````0````$`
M```!`````P`'X#!O_@\!`````0````$````!`````0````$````#``@`,&_^
M!P$````!`````0````$````!`````0````,`""`P;_W_`0````$````!````
M`0````$````!`````P`(0#!O_?<!`````0````$````!`````0````$````#
M``A@,&_][P$````!`````0````$````!`````0````,`"(`P;_WG`0````$`
M```!`````0````$````!`````P`(H#!O_=\!`````0````$````!`````0``
M``$````#``C`,&_]UP$````!`````0````$````!`````0````,`".`P;_W/
M`0````$````!`````0````$````!`````P`)`#!O_<<!`````0````$````!
M`````0````$````#``D@,&_]OP$````!`````0````$````!`````0````,`
M"4`P;_VW`0````$````!`````0````$````!`````P`)8#!O_:\!`````0``
M``$````!`````0````$````#``F`,&_]IP$````!`````0````$````!````
M`0````,`":`P;_V?`0````$````!`````0````$````!`````P`)P#!O_9<!
M`````0````$````!`````0````$````#``G@,&_]CP$````!`````0````$`
M```!`````0````,`"@`P;_V'`0````$````!`````0````$````!`````P`*
M(#!O_7\!`````0````$````!`````0````$````#``I`,&_]=P$````!````
M`0````$````!`````0````,`"F`P;_UO`0````$````!`````0````$````!
M`````P`*@#!O_6<!`````0````$````!`````0````$`````````_____P``
M`````%OI```````0O"A'0T,Z("A'3E4I(#0N-BXP(#(P,3$P,C$R("A2960@
M2&%T(#0N-BXP+3`N-RD``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT
M86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M````````````````````````````````````````````````````````````
M``L````!``````````(``````!`"``````````(``````````!4`````````
M```````````!```````````````3````!P`````````"```````0`A@`````
M```"&``````````@````````````````````!```````````````(0````<`
M`````````@``````$`(X`````````C@`````````)```````````````````
M``0``````````````#1O___V``````````(``````!`"8`````````)@````
M`````L`````%```````````````(```````````````^````"P`````````"
M```````0!2`````````%(`````````CH````!@````$`````````"```````
M```8````1@````,``````````@``````$`X(````````#@@````````%%```
M``````````````````$``````````````$YO____``````````(``````!`3
M'````````!,<`````````+X````%```````````````"``````````(```!;
M;____@`````````"```````0$^`````````3X`````````"`````!@````(`
M````````"```````````````:@````0``````````@``````$!1@````````
M%&``````````2`````4```````````````@`````````&````'0````$````
M``````(``````!`4J````````!2H````````!Y@````%````%@`````````(
M`````````!@```!^`````0`````````&```````0'$`````````<0```````
M``!$````````````````````!```````````````A`````$`````````!@``
M````$!R@````````'*`````````_P````````````````````"``````````
M`````(H````!``````````8``````!!<8````````%Q@`````````!0`````
M```````````````$``````````````"0`````0`````````"```````07'@`
M``````!<>````````%^X````````````````````"```````````````F```
M``$``````````@``````$+PP````````O#``````````Y```````````````
M``````0``````````````*8````!``````````(``````!"]&````````+T8
M`````````J0````````````````````(``````````````"P`````0``````
M```#```````@P`````````#````````````0````````````````````"```
M````````````MP````$``````````P``````(,`0````````P!``````````
M$`````````````````````@``````````````+X````!``````````,`````
M`"#`(````````,`@``````````@````````````````````(````````````
M``##````!@`````````#```````@P"@```````#`*`````````)@````!@``
M````````````"``````````0````S`````$``````````P``````(,*(````
M````PH@`````````*`````````````````````@`````````"````'D````!
M``````````<``````"##`````````,,`````````"J``````````````````
M``$``````````"````#1`````0`````````#```````@S:````````#-H```
M```````8````````````````````"```````````````UP````@`````````
M`P``````(,VX````````S;@````````06`````````````````````@`````
M`````````-P````!`````````#```````````````````,VX`````````"X`
M```````````````````!``````````$````!`````P``````````````````
J``````````#-Y@````````#E`````````````````````0``````````
